@@ -1,3 +1,6 @@
+mkdir -p build
+cd build
+
 if [[ ${HOST} =~ .*linux.* ]]; then
   sed -i 's|_qt5gui_find_extra_libs(EGL.*)|_qt5gui_find_extra_libs(EGL "EGL" "" "")|g' $PREFIX/lib/cmake/Qt5Gui/Qt5GuiConfigExtras.cmake
   sed -i 's|_qt5gui_find_extra_libs(OPENGL.*)|_qt5gui_find_extra_libs(OPENGL "GL" "" "")|g' $PREFIX/lib/cmake/Qt5Gui/Qt5GuiConfigExtras.cmake
@@ -5,5 +8,9 @@ fi
 
 PIVY_CPP_FLAGS='-std=c++1z '
 
-$PYTHON setup.py clean
-$PYTHON setup.py install
+cmake -G "Ninja" \
+    -D CMAKE_BUILD_TYPE="Release" \
+    -D CMAKE_INSTALL_PREFIX:FILEPATH=$PREFIX \
+    ..
+
+ninja install
\ No newline at end of file
